<?php
/*
 * Portfolio Meta Box for Pages
 */

add_action('admin_menu', 'ht_portfolio_add_custom_box');
function ht_portfolio_add_custom_box() {
	global $theme_name;
	add_meta_box('ht_portfolio', $theme_name . '- Unlimited Blog/Portfolio Options', 'ht_portfolio_custom_box', 'page', 'normal', 'core');
}

function ht_portfolio_custom_box() {
	global $post, $categories;
	 
	$ht_page_type_category = get_post_meta($post->ID,'_ht_page_type_category',true);
	$ht_item_number = get_post_meta($post->ID,'_ht_item_number',true);
	$ht_page_type = get_post_meta($post->ID,'_ht_page_type',true);
	$ht_portfolio_layout = get_post_meta($post->ID,'_ht_portfolio_layout',true);


	
	/* array custom page types */
	$ht_page_types = array(
		"page" => "Page",
		"blog" => "Blog",
		"portfolio" => "Portfolio"			 		 
	);

	/* array of portfolio layouts */
	$portfolio_templates = array(
		"1c" => "1 Column",
		"2c" => "2 Columns",
		"3c" => "3 Columns",
		"4c" => "4 Columns",
		"5c" => "5 Columns"						 		 
	);

	/* for security */
	echo '<input type="hidden" name="ht_portfolio_noncename" id="ht_portfolio_noncename"
	 	  value="'.wp_create_nonce('ht-portfolio').'" />';

	/* page type form element */
	echo '<p class="separate"><strong>Select the page type</strong>
	 	  <label for="ht_page_type" class="screen-reader-text">Page Type</label>';
			
	echo '<select name="ht_page_type" id="ht_page_type" size="1">';
	foreach ($ht_page_types as $type_id=>$type_name) {
		echo '<option value="'.$type_id.'"';
		if ($ht_page_type == $type_id) echo ' selected="selected"';
		echo '>'.$type_name.'</option>';
	}
		echo '</select></p>';
	


	/* Category */
	echo '<p class="separate"><strong>Select a category</strong>
	 	  <label for="ht_page_type_category" class="screen-reader-text">Category</label>';

	echo '<select name="ht_page_type_category" id="ht_page_type_category" size="1">';
	foreach ($categories as $id=>$category) {
		echo '<option value="'.$id.'"';
		if ($ht_page_type_category == $id) echo ' selected="selected"';
		echo '>'.$category.'</option>';
	}

	echo "</select></p>";

	/* Number of items per pages */
	echo '<p class="separate"><strong>Items per page?</strong>
		  <label for="ht_item_number" class="screen-reader-text">Image per page?</label>
		  <input value="'.$ht_item_number  .'" type="text" name="ht_item_number" id="ht_item_number"/>
		  </p>';

	/* portfolio layouts */
	
 	echo '<p class="separate"><strong>Select the Portfolio Layout</strong>
	 	  <label for="ht_portfolio_layout" class="screen-reader-text">Portfolio Layout</label>';
	
	echo '<select name="ht_portfolio_layout" id="ht_portfolio_layout" size="1">';
	foreach ($portfolio_templates as $template_id=>$template_name) {
		echo '<option value="'.$template_id.'"';
		if ($ht_portfolio_layout == $template_id) echo ' selected="selected"';
		echo '>'.$template_name.'</option>';
	}
		echo "</select></p>";
}

add_action('save_post', 'ht_portfolio_save_postdata');

function ht_portfolio_save_postdata($post_id) {
	if (!wp_verify_nonce($_POST['ht_portfolio_noncename'], 'ht-portfolio')) return $post_id;

	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) return $post_id;

	$ht_page_type_category = $_POST['ht_page_type_category'];
	$ht_item_number = $_POST['ht_item_number'];
	$ht_portfolio_link = $_POST['ht_portfolio_link'];
	$ht_portfolio_vlink = $_POST['ht_portfolio_vlink'];
	$ht_page_type = $_POST['ht_page_type'];
	$ht_portfolio_layout = $_POST['ht_portfolio_layout'];

	update_post_meta($post_id, '_ht_page_type_category', $ht_page_type_category);
	update_post_meta($post_id, '_ht_item_number', $ht_item_number);
	update_post_meta($post_id, '_ht_page_type', $ht_page_type);
	update_post_meta($post_id, '_ht_portfolio_layout', $ht_portfolio_layout);
	



}


/*
 * Portfolio Custom Fields
 */
add_action('admin_menu', 'ht_portfolio_item_box');

function ht_portfolio_item_box() {
	global $theme_name;

	add_meta_box('ht_portfolio_item', $theme_name . '- Posts Options', 'ht_portfolio_item_custom_box', 'post', 'normal', 'high');
}

function ht_portfolio_item_custom_box() {
	global $post;

	$ht_portfolio_link = get_post_meta($post->ID,'_ht_portfolio_link',true);
	$ht_portfolio_vlink = get_post_meta($post->ID,'_ht_portfolio_vlink',true);
	$ht_portfolio_post_layout = get_post_meta($post->ID,'_ht_portfolio_post_layout',true);
	
	if($ht_portfolio_post_layout =="true") $ht_portfolio_post_layout = 'checked="checked"';
	

	echo '<input type="hidden" name="ht_portfolio_noncename" id="ht_portfolio_noncename"
	 	  value="'.wp_create_nonce('ht-portfolio-item').'" />';

	echo '<p class="separate">
	 	  <strong>Enable Full-Width Post Layout?</strong><span class="ht_desc"> / Default posts layout has sidebar. If you like to remove the sidebar, check this box.</span><br /><br />

	 	  <label for="ht_portfolio_post_layout" class="">Full-width post layout? </label>
		  <input '. $ht_portfolio_post_layout .' type="checkbox" name="ht_portfolio_post_layout" value="true" id="ht_portfolio_post_layout" />
	 	  </p>';

	echo '<p class="separate">
	 	  <strong>Portfolio Link</strong><span class="ht_desc"> / Enter the URL of the project used for "Visit" button.</span><br />
	 	  <label for="ht_portfolio_link" class="screen-reader-text">Portfolio Link?</label>
	 	  <input value="'.$ht_portfolio_link  .'" type="text" class="full_text" name="ht_portfolio_link" id="ht_portfolio_link"/>
	 	  </p>';

	echo '<p class="separate">
		  <strong>Portfolio Video Link</strong><span class="ht_desc"> / To embed a video into them portfolio you can paste its link here.</span><br />
		  <label for="ht_portfolio_vlink" class="screen-reader-text">Portfolio Video Link?</label>
		  <input value="'.$ht_portfolio_vlink  .'" type="text" class="full_text" name="ht_portfolio_vlink" id="ht_portfolio_vlink"/>
		  </p>';		
}

add_action('save_post', 'ht_portfolio_item_save_postdata');

function ht_portfolio_item_save_postdata($post_id) {
	if (!wp_verify_nonce($_POST['ht_portfolio_noncename'], 'ht-portfolio-item')) return $post_id;

	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) return $post_id;

	$ht_portfolio_link = $_POST['ht_portfolio_link'];
	$ht_portfolio_vlink = $_POST['ht_portfolio_vlink'];
	$ht_portfolio_post_layout = $_POST['ht_portfolio_post_layout'];


	update_post_meta($post_id, '_ht_portfolio_link', $ht_portfolio_link);
	update_post_meta($post_id, '_ht_portfolio_vlink', $ht_portfolio_vlink);
	update_post_meta($post_id, '_ht_portfolio_post_layout', $ht_portfolio_post_layout);


}
/*
 * Sidebar Options
 */

add_action('admin_menu', 'ht_sidebar_options');
function ht_sidebar_options() {
	global $theme_name;
	add_meta_box('ht_sidebar_options', $theme_name . '- Sidebar Options', 'ht_sidebar_options_box', 'page', 'normal', 'high');
		add_meta_box('ht_sidebar_options', $theme_name . '- Sidebar Options', 'ht_sidebar_options_box', 'post', 'normal', 'high');
}

function ht_sidebar_options_box() {
		global $post;

	$selected_sidebar = get_post_meta($post->ID,'selected_sidebar',true);
	$sidebar_alignment = get_post_meta($post->ID,'sidebar_alignment',true);
	
	
	/* for security */
	echo '<input type="hidden" name="ht_sidebar_noncename" id="ht_sidebar_noncename"
	 	  value="'.wp_create_nonce('ht-sidebar').'" />';

	/* page type form element */
	echo '<p class="separate"><strong>Custom Sidebar</strong>
	 	  <label for="selected_sidebar" class="screen-reader-text">Custom Sidebar</label>';
			
	echo '<select name="selected_sidebar" id="selected_sidebar" size="1">';
	if($selected_sidebar == ''){ $selected= " selected";}
	echo '<option value="" '.$selected.'>Select A Sidebar</option>';
	
	$sidebars = ht_sidebar_generator::get_sidebars();
	if(is_array($sidebars) && !empty($sidebars)){
	foreach($sidebars as $sidebar){
		if($selected_sidebar == $sidebar){
			echo "<option value='$sidebar' selected>$sidebar</option>\n";
		}else{
			echo "<option value='$sidebar'>$sidebar</option>\n";
		}
	}
}
	echo '</select></p>';
	
	// Sidebar Alignment
	echo '<p class="separate"><strong>Sidebar Alignment</strong>
	 	  <label for="selected_sidebar" class="screen-reader-text">Sidebar Alignment</label>';
			
	echo '<select name="sidebar_alignment" id="sidebar_alignment" size="1">';
	if($sidebar_alignment == '' || $sidebar_alignment == 'Right'){ $selected= " selected";}
	echo '<option value="Right" '.$selected.'>Right Sidebar</option>';	
	if($sidebar_alignment == 'Left'){ $lselected= " selected";}
	echo '<option value="Left" '.$lselected.'>Left Sidebar</option>';		
	
	echo '</select></p>';	


}

add_action('save_post', 'ht_sidebar_options_save');

function ht_sidebar_options_save($post_id) {
	if (!wp_verify_nonce($_POST['ht_sidebar_noncename'], 'ht-sidebar')) return $post_id;

	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) return $post_id;

	$selected_sidebar = $_POST['selected_sidebar'];
	$sidebar_alignment = $_POST['sidebar_alignment'];

	update_post_meta($post_id, 'selected_sidebar', $selected_sidebar);
	update_post_meta($post_id, 'sidebar_alignment', $sidebar_alignment);

}


/*
 * Image Resizer
 */

function ht_image_resize($height,$width,$img_url) {

	$image['url'] = $img_url;
	$image_path = explode($_SERVER['SERVER_NAME'], $image['url']);
	$image_path = $_SERVER['DOCUMENT_ROOT'] . $image_path[1];
	$image_info = @getimagesize($image_path);

	if (!$image_info)
	$image_info = @getimagesize($image['url']);

	$image['width'] = $image_info[0];
	$image['height'] = $image_info[1];
	if($img_url != "" && ($image['width'] > $width || $image['height'] > $height || !isset($image['width']))){
		$img_url = HT_JS_PATH."/thumb.php?src=$img_url&amp;w=$width&amp;h=$height&amp;zc=1&amp;q=100";
	}

	return $img_url;
}



/*
 * New Excerpt Function
 */
function ht_excerpt($length, $ellipsis) {
	$text = get_the_content();
	$text = preg_replace('`\[[^\]]*\]`','',$text);
	$text = strip_tags($text);
	$text = substr($text, 0, $length);
	$text = substr($text, 0, strripos($text, " "));
	$text = $text.$ellipsis;
	return $text;
}

/*
 * Enable Threaded Comments
 */
function enable_threaded_comments(){
	if (!is_admin()) {
		if (is_singular() AND comments_open() AND (get_option('thread_comments') == 1))
		wp_enqueue_script('comment-reply');
	}
}
add_action('get_header', 'enable_threaded_comments');

/*
 * Custom Comments
 */
function custom_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	?>

<div <?php comment_class(); ?> id="div-comment-<?php comment_ID() ?>">
<div class="comment-entry" id="comment-<?php comment_ID(); ?>">
 <span class="reply">
  <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
  </span>
 <div><span class="frame"><?php if ($args['avatar_size'] != 0) echo get_avatar( $comment, $args['avatar_size'] ); ?></span>
    
    <div class="body">
    <cite><?php comment_author_link() ?></cite> &raquo; <span class="meta">
      <?php comment_date('d. M, Y'); ?>
      </span>
      <?php if ($comment->comment_approved == '0') : ?>
      <em>
      <?php _e('Your comment is awaiting moderation.') ?>
      </em> <br />
      <?php endif; ?>
      <div class="commenttext">
        <?php comment_text() ?>
      </div>
    </div>
    <div class="fix"></div>
    </div>

</div>
<!-- END section -->
<?php
}


/*
 * Related Posts
 */
function ht_related_post() {
?>
<?php
	global $post, $wpdb;
	$backup = $post;  // backup the current object
	$tags = wp_get_post_tags($post->ID);
	$tagIDs = array();
	if ($tags) {
		$tagcount = count($tags);
		for ($i = 0; $i < $tagcount; $i++) {
			$tagIDs[$i] = $tags[$i]->term_id;
		}
		$args=array(
	    'tag__in' => $tagIDs,
	    'post__not_in' => array($post->ID),
	    'showposts'=>4,
	    'caller_get_posts'=>1
		);
		$my_query = new WP_Query($args);
		if( $my_query->have_posts() ) { $related_post_found = true; ?>
 <div class="related-posts">

  <h3>Related Posts</h3>
  <ul class="thumb-list">
	<?php
	$i=1;
	while ($my_query->have_posts()) : $my_query->the_post(); 
    
	$post_id = get_the_ID();
	$post_thumbnail = get_the_post_thumbnail($post_id, array(60, 60), array("class" => "post_thumbnail"));

	if(!$post_thumbnail){
		$post_thumbnail = '<img alt="image" src="'.get_template_directory_uri() .'/images/empty_thumb.gif" />';
	}
?>
    <li class="one_half <?php if(($i%2)==0 && $i<>0){ echo ' last';}?>">
    <a class="fl" href="<?php the_permalink() ?>" title="<?php the_title(); ?>">
    <span class="frame"><?php echo $post_thumbnail;?></span></a>
      <p><a class="thumb-title" href="<?php the_permalink() ?>"	rel="bookmark"> <?php the_title(); ?></a><br />
        <span class="date">
        <?php the_time('F j, Y'); ?>
        </span>
      <br class="fix" />
      </p>
    </li>
    <?php   
	$i++; 
	endwhile; 
	?>
  </ul>
  </div>

  <?php 
  }
	}

wp_reset_query();

?>

<?php

}

/*
 * Change MORE sign
 */
function new_excerpt_more($more) {
	return ' ...';
}
add_filter('excerpt_more', 'new_excerpt_more');




/*
 * Enable Post Thumbnails
 */
if ( function_exists('add_theme_support') ) {
	add_theme_support('post-thumbnails');
}



/*
 * Register Widgets
 */
function the_widgets_init() {
	if ( !function_exists('register_sidebars') )
	return;
	register_sidebars(1,array('name' => 'Default Sidebar', 'id'=>'default-sidebar', 'before_widget' => '<div id="%1$s" class="%2$s widget">','after_widget' => '</div>','before_title' => '<h3>','after_title' => '</h3>'));

	register_sidebar(array(	'name'=>__('Footer-1'),	'id'=> 'footer-1','before_widget' => '<div id="footer%1$s" class="%2$s">','after_widget'  => '</div>','before_title'  => '<h3>','after_title' => '</h3>' ));
	register_sidebar(array(	'name'=>__('Footer-2'),	'id'=> 'footer-2','before_widget' => '<div id="footer%1$s" class="%2$s">','after_widget'  => '</div>','before_title'  => '<h3>','after_title' => '</h3>' ));
	register_sidebar(array(	'name'=>__('Footer-3'),	'id'=> 'footer-3','before_widget' => '<div id="footer%1$s" class="%2$s">','after_widget'  => '</div>','before_title'  => '<h3>','after_title' => '</h3>' ));
	register_sidebar(array(	'name'=>__('Footer-4'),	'id'=> 'footer-4','before_widget' => '<div id="footer%1$s" class="%2$s">','after_widget'  => '</div>','before_title'  => '<h3>','after_title' => '</h3>' ));
	register_sidebar(array(	'name'=>__('Footer-5'),	'id'=> 'footer-5','before_widget' => '<div id="footer%1$s" class="%2$s">','after_widget'  => '</div>','before_title'  => '<h3>','after_title' => '</h3>' ));	
	

	 
}

add_action( 'init', 'the_widgets_init' );

/* 
 * Enabling shortcodes in text widgets
 */
 add_filter('widget_text', 'do_shortcode');
 
/*
 * Misc
 */
 
register_nav_menu( 'nav', 'Primary Navigation of Sleex' );
function ht_filter_wp_title( $title, $separator ) {
	if ( is_feed() )
	return $title;

	global $paged, $page;

	if ( is_search() ) {
		$title = sprintf( __( 'Search results for %s'), '"' . get_search_query() . '"' );
		if ( $paged >= 2 )
		$title .= " $separator " . sprintf( __( 'Page %s' ), $paged );
		$title .= " $separator " . get_bloginfo( 'name', 'display' );
		return $title;
	}

	$title .= get_bloginfo( 'name', 'display' );

	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
	$title .= " $separator " . $site_description;

	if ( $paged >= 2 || $page >= 2 )
	$title .= " $separator " . sprintf( __( 'Page %s' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'ht_filter_wp_title', 10, 2 );

add_post_type_support( 'page', 'excerpt' );

/*
 * Author Bio
 */

function ht_author_bio() { ?>
<div id="author-info" class="gradient-box">
  <div class="border-style">
    <div class="inner"><span class="frame fl"><?php echo get_avatar( get_the_author_email(), '60' ); ?></span>
      <p><strong>
        <?php the_author_link(); ?>
        </strong> <br />
        <?php the_author_description(); ?>
      </p>
      <div class="fix"></div>
    </div>
  </div>
</div>
<?php
}
?>
