<?php
/**
 * HighThemes Recent Posts Widget
 */

class HT_Recent_Posts extends WP_Widget {
	
	function HT_Recent_Posts() {
		global  $theme_name;
		// define widget title and description
		$widget_ops = array('classname' => 'ht_recent_posts',
							'description' => __( 'The most recent posts with thumbnails') );
		// register the widget
		$this->WP_Widget('HT_Recent_Posts',$theme_name . " " . __('Recent Posts'), $widget_ops);
	
	}
	
	// display the widget in the theme
	function widget( $args, $instance ) {
		global $wpdb;
		extract($args);
		
		$exclude_blog_cats = preg_replace("!(\d)+!","-${0}$0", get_option('ht_excluded_cats'));
		$posts_number  = (int) $instance['posts_number'];
		$posts = get_posts("cat=$exclude_blog_cats&numberposts=$posts_number&offset=0");

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Posts') : $instance['title'], $instance, $this->id_base);

		echo $before_widget;
		
		if ( $title ) echo $before_title . $title . $after_title;
		

		if($posts){ ?>

		<ul class="thumb-list">
		<?php foreach($posts as $post){
		
		$post_title = stripslashes($post->post_title);
		$post_date = $post->post_date;
		$post_date = mysql2date('F j, Y', $post_date, false);
		$permalink = get_permalink($post->ID);

		$post_thumbnail = get_the_post_thumbnail($post->ID, array(60, 60), array("class" => "post_thumbnail"));

		if(!$post_thumbnail){
			$post_thumbnail = '<img alt="image" src="'.get_template_directory_uri() .'/images/empty_thumb.gif" />';
		}
		?>
		<li><a class="fl" href="<?php echo $permalink; ?>" title="<?php echo $post_title; ?>">
        <span class="frame"><?php echo $post_thumbnail;?></span></a>
		<a class="thumb-title" href="<?php echo $permalink; ?>" rel="bookmark"><?php echo $post_title; ?></a><br />
		<span class="date"><?php echo $post_date; ?></span></li>
		<?php } ?>
		</ul>
		<?php }
		echo $after_widget;
		
		
		//end
	}
	
	// update the widget when new options have been entered
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;
		
		// replace old with new
		$instance['posts_number'] = (int) strip_tags($new_instance['posts_number']);
		$instance['title'] =  strip_tags($new_instance['title']);
		
		return $instance;
	}
	
	// print the widget option form on the widget management screen
	function form( $instance ) {

	// combine provided fields with defaults
	$instance = wp_parse_args( (array) $instance, array( 'posts_number' => 3, 'title'=>'Recent Posts' ) );
	$posts_number = (int) strip_tags($instance['posts_number']);
	$title =  strip_tags($instance['title']);
	
	// print the form fields
?>
	
	<p><label for="<?php echo $this->get_field_id('title'); ?>">
	<?php _e('Title:'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo
		esc_attr($title); ?>" /></p>    
        
    <p><label for="<?php echo $this->get_field_id('posts_number'); ?>">
	<?php _e('Number of Posts:'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('posts_number'); ?>" name="<?php echo $this->get_field_name('posts_number'); ?>" type="text" value="<?php echo
		esc_attr($posts_number); ?>" /></p>
	<?php
	}
	}
	

/**
 * HighThemes Popular Posts
 */

class HT_Popular_Posts extends WP_Widget {
	
	function HT_Popular_Posts() {
		global  $theme_name;
		// define widget title and description
		$widget_ops = array('classname' => 'ht_popular_posts',
							'description' => __( 'The most popular posts with thumbnails') );
		// register the widget
		$this->WP_Widget('HT_Popular_Posts',$theme_name . " " . __('Popular Posts'), $widget_ops);
	
	}
	
	// display the widget in the theme
	function widget( $args, $instance ) {
		global $wpdb;
		extract($args);
		
	$pop_posts =  (int) strip_tags($instance['posts_number']);
	
	if (empty($pop_posts) || $pop_posts < 1) $pop_posts = 3;
	$now = gmdate("Y-m-d H:i:s",time());
	$lastmonth = gmdate("Y-m-d H:i:s",gmmktime(date("H"), date("i"), date("s"), date("m")-12,date("d"),date("Y")));
	$popularposts = "SELECT ID, post_title, post_date, COUNT($wpdb->comments.comment_post_ID) AS 
					'stammy' FROM $wpdb->posts, $wpdb->comments WHERE comment_approved = '1' 
					AND $wpdb->posts.ID=$wpdb->comments.comment_post_ID AND post_status = 'publish'  
					AND comment_status = 'open' GROUP BY $wpdb->comments.comment_post_ID ORDER BY stammy DESC LIMIT ".$pop_posts;
	
	$posts = $wpdb->get_results($popularposts);
	$popular = '';
		
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Popular Posts') : $instance['title'], $instance, $this->id_base);

		echo $before_widget;
		
		if ( $title ) echo $before_title . $title . $after_title;
		

		if($posts){ ?>
		<ul class="thumb-list">
		<?php foreach($posts as $post){
			$post_title = stripslashes($post->post_title);
			$post_date = $post->post_date;
			$post_date = mysql2date('F j, Y', $post_date, false);
			$permalink = get_permalink($post->ID);

			$post_thumbnail = get_the_post_thumbnail($post->ID, array(60, 60), array("class" => "post_thumbnail"));

			if(!$post_thumbnail){
			$post_thumbnail = '<img alt="image" src="'.get_template_directory_uri() .'/images/empty_thumb.gif" />';
		}
		?>
		<li><a class="fl" href="<?php echo $permalink; ?>"	title="<?php echo $post_title; ?>"> <span class="frame"><?php echo $post_thumbnail;?></span></a>
		<a class="thumb-title" href="<?php echo $permalink; ?>" rel="bookmark"><?php echo $post_title; ?></a><br />
		<span class="date"><?php echo $post_date; ?></span></li>
		<?php } ?>
		</ul>
		<?php }
		echo $after_widget;
		
		
		//end
	}
	
	// update the widget when new options have been entered
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;
		
		// replace old with new
		$instance['posts_number'] = (int) strip_tags($new_instance['posts_number']);
		$instance['title'] =  strip_tags($new_instance['title']);
		
		return $instance;
	}
	
	// print the widget option form on the widget management screen
	function form( $instance ) {

	// combine provided fields with defaults
	$instance = wp_parse_args( (array) $instance, array( 'posts_number' => 3, 'title' =>'Popular Posts' ) );
	$posts_number = (int) strip_tags($instance['posts_number']);
	$title =  strip_tags($instance['title']);
	
	// print the form fields
?>
	<p><label for="<?php echo $this->get_field_id('title'); ?>">
	<?php _e('Title: '); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo
		esc_attr($title); ?>" /></p>
        
	<p><label for="<?php echo $this->get_field_id('posts_number'); ?>">
	<?php _e('Number of Posts:'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('posts_number'); ?>" name="<?php echo $this->get_field_name('posts_number'); ?>" type="text" value="<?php echo
		esc_attr($posts_number); ?>" /></p>
	<?php
	}
	}	

/**
 * HighThemes Recent Tweets
 */

class HT_Recent_Tweets extends WP_Widget {
	
	function HT_Recent_Tweets() {
		
		global  $theme_name;
		// define widget title and description
		$widget_ops = array('classname' => 'ht_recent_tweets',
							'description' => __( 'Recent tweets') );
		// register the widget
		$this->WP_Widget('HT_Recent_Tweets',$theme_name . " " . __('Recent Tweets'), $widget_ops);
	
	}
	
	// display the widget in the theme
	function widget( $args, $instance ) {
		global $wpdb, $tweet_widget_number;
		extract($args);
		
		$tweet_widget_number++;
		
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Tweets') : $instance['title'], $instance, $this->id_base);

		echo $before_widget;
		
		if ( $title ) echo $before_title . $title . $after_title;

	?>
    <script type="text/javascript">
   //<![CDATA[
		getTwitters('<?php echo $this->id_base . "_" . $tweet_widget_number;?>', {
        id: '<?php echo get_option('ht_twitter_id');?>', 
        clearContents: false, // leave the original message in place
        count: <?php if (isset($instance['tweets_number']) && is_numeric($instance['tweets_number']))echo $instance['tweets_number'];else echo 3;?>, 
        withFriends: true,
        ignoreReplies: true,
        newwindow: true,
		 template: '<span class="twitterStatus">%text%</span> <span class="twitterTime"><a href="http://twitter.com/%user_screen_name%/statuses/%id%">%time%</a></span>'
    });
    //]]>
</script>
<div class="recent-tweets" id="<?php echo $this->id_base . "_" . $tweet_widget_number;?>"></div>
    <?php
		echo $after_widget;
		
		//end
	}
	
	// update the widget when new options have been entered
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);

		// replace old with new
		$instance['tweets_number'] = (int) strip_tags($new_instance['tweets_number']);
		return $instance;
	}
	
	// print the widget option form on the widget management screen
	function form( $instance ) {

	// combine provided fields with defaults
	$instance = wp_parse_args( (array) $instance, array( 'tweets_number' => 3, 'title' => 'Recent Tweets' ) );
	$tweets_number = (int) strip_tags($instance['tweets_number']);
	$title = strip_tags($instance['title']);
	
	
	// print the form fields
?>
	<p><label for="<?php echo $this->get_field_id('title'); ?>">
	<?php _e('Title:'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo
		esc_attr($title); ?>" /></p>
    
    
    <p><label for="<?php echo $this->get_field_id('tweets_number'); ?>">
	<?php _e('Number of Tweets:'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('tweets_number'); ?>" name="<?php echo $this->get_field_name('tweets_number'); ?>" type="text" value="<?php echo
		esc_attr($tweets_number); ?>" /></p>
	<?php
	}
	}

/**
 * Highthemes Sub Navigation
 */

class HT_Sub_Navigatioin extends WP_Widget {
	
	function HT_Sub_Navigatioin() {
		
		global  $theme_name;
		// define widget title and description
		$widget_ops = array('classname' => 'ht_sub_navigation',
							'description' => __( 'Showing subpages on sidebar') );
		// register the widget
		$this->WP_Widget('HT_Sub_Navigatioin',$theme_name . " " . __('Sub Pages'), $widget_ops);
	
	}
	
	// display the widget in the theme
	function widget( $args, $instance ) {
		global $wpdb, $post;
		extract($args);
		
	 	if ( !is_page() ) return false;

    	if ($post->post_parent != 0)
    	$parent = get_post($post->post_parent);
    	else
    	$parent = false;
	  
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Sub Pages') : $instance['title'], $instance, $this->id_base);

		echo $before_widget;
		
		if ( $title ) echo $before_title . $title . $after_title;


 		// Default Args for selecting sub pages
    	$page_args = array( 'title_li' => '',
                        'child_of' => $post->ID,
                        'depth'    => 1,
                        'echo'     => false );

      	// Read the subpages again
     	$page_listing = wp_list_pages($page_args);
	    //if ( !$page_listing ) return false;


        echo  '<ul>';
        echo $page_listing;
     	echo '</ul>';
		echo $after_widget;
		
		//end
	}
	
	// update the widget when new options have been entered
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);

		return $instance;
	}
	
	// print the widget option form on the widget management screen
	function form( $instance ) {

	// combine provided fields with defaults
	$instance = wp_parse_args( (array) $instance, array( 'title' => 'Sub Pages' ) );
	$title = strip_tags($instance['title']);
	
	
	// print the form fields
?>
	<p><label for="<?php echo $this->get_field_id('title'); ?>">
	<?php _e('Title:'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo
		esc_attr($title); ?>" /></p>
    

	<?php
	}
	}
	
	

/**
 * Highthemes Flickr
 */

class HT_Flickr extends WP_Widget {
	
	function HT_Flickr() {
		
		global  $theme_name;
		// define widget title and description
		$widget_ops = array('classname' => 'ht_flickr_widget',
							'description' => __( 'Pulls in images from your Flickr account.') );
		// register the widget
		$this->WP_Widget('HT_Flickr',$theme_name . " " . __('Flickr'), $widget_ops);
	
	}
	
	// display the widget in the theme
	function widget( $args, $instance ) {
		extract($args);
		
	  	$number = (int) strip_tags($instance['number']);
	  	$id = strip_tags($instance['id']);
		
		echo $before_widget;
		

?>
<div id="flickr">
<h3>Photos on <span>flick<span>r</span></span></h3>
<div class="wrap">
<div class="fix"></div>
<script type="text/javascript"
	src="http://www.flickr.com/badge_code_v2.gne?count=<?php echo $number; ?>&amp;display=latest&amp;size=s&amp;layout=x&amp;source=user&amp;user=<?php echo $id; ?>"></script>
<div class="fix"></div>
</div>
</div>
<?php
		echo $after_widget;
		
		//end
	}
	
	// update the widget when new options have been entered
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;
		$instance['number'] = (int) strip_tags($new_instance['number']);
		$instance['id'] = strip_tags($new_instance['id']);

		return $instance;
	}
	
	// print the widget option form on the widget management screen
	function form( $instance ) {

	// combine provided fields with defaults
	$instance = wp_parse_args( (array) $instance, array( 'id' => '', 'number'=>6 ) );
	$id = strip_tags($instance['id']);
	$number = strip_tags($instance['number']);
	
	
	
	// print the form fields
?>
	<p><label for="<?php echo $this->get_field_id('id'); ?>">
	<?php _e('Flickr ID (<a href="http://www.idgettr.com" target="_blank">idGettr</a>):'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('id'); ?>" name="<?php echo $this->get_field_name('id'); ?>" type="text" value="<?php echo
		esc_attr($id); ?>" /></p>

	<p><label for="<?php echo $this->get_field_id('number'); ?>">
	<?php _e('Number:'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo
		esc_attr($number); ?>" /></p>        
    

	<?php
	}
	}
	
/**
 * Highthemes Contact Details
 */

class HT_Contact_Details extends WP_Widget {
	
	function HT_Contact_Details() {
		
		global  $theme_name;
		// define widget title and description
		$widget_ops = array('classname' => 'ht_contact_details',
							'description' => __( 'Contact Details for Sidebar') );
		// register the widget
		$this->WP_Widget('HT_Contact_Details',$theme_name . " " . __('Contact Details'), $widget_ops);
	
	}
	
	// display the widget in the theme
	function widget( $args, $instance ) {
		extract($args);
		
		
		$instance['contact_address'] = strip_tags(stripslashes($instance['contact_address']));
		$instance['contact_tels'] = strip_tags(stripslashes($instance['contact_tels']));
		$instance['contact_email'] = stripslashes($instance['contact_email']);
		$instance['contact_title'] = strip_tags(stripslashes($instance['contact_title']));
		$instance['contact_map'] = strip_tags(stripslashes($instance['contact_map']));		
		
		$gallery_image_url = ht_image_resize($height='200',$width='283',$instance['contact_map']);
		
		$title = apply_filters('widget_title', empty($instance['contact_title']) ? __('Contact') : $instance['contact_title'], $instance, $this->id_base);
		
		echo $before_widget;
				if ( $title ) echo $before_title . $title . $after_title;


?>
<div id="contact-details">

<p class="textwidget"><?php if($instance['contact_map'] <> ''):?> <a class="zoom" href="<?php echo $instance['contact_map'];?>" title=""	rel="prettyPhoto[gallery]">
 <span class="frame post-image"> <img src="<?php echo $gallery_image_url;?>" alt="<?php the_title_attribute();?>" /> </span> </a></p>
	<?php endif;?>
<address><?php echo stripslashes(nl2br($instance['contact_address']));?></address>
<p class="tel-numbers"><?php echo stripslashes(nl2br($instance['contact_tels']));?></p>
<span class="email"><?php echo stripslashes($instance['contact_email']);?></span>

</div>
<?php
		echo $after_widget;
		
		//end
	}
	
	// update the widget when new options have been entered
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;
		$instance['contact_map'] = strip_tags($new_instance['contact_map']);
		$instance['contact_title'] = strip_tags($new_instance['contact_title']);
		$instance['contact_address'] = strip_tags($new_instance['contact_address']);
		$instance['contact_tels'] = strip_tags($new_instance['contact_tels']);
		$instance['contact_email'] = $new_instance['contact_email'];

		return $instance;
	}
	
	// print the widget option form on the widget management screen
	function form( $instance ) {

	// combine provided fields with defaults
	$instance = wp_parse_args( (array) $instance, array( 'contact_title' => 'Contact Info', 'contact_address'=>'lorem ipsum dolor sit amet', 'contact_tels'=>'111-222-333' ) );
	$contact_map = strip_tags($instance['contact_map']);
	$contact_title = strip_tags($instance['contact_title']);
	$contact_address = strip_tags($instance['contact_address']);
	$contact_tels = strip_tags($instance['contact_tels']);
	$contact_email = $instance['contact_email'];
	
	
	
	// print the form fields
?>
	<p><label for="<?php echo $this->get_field_id('contact_map'); ?>">
	<?php _e('Map Image URL:'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('contact_map'); ?>" name="<?php echo $this->get_field_name('contact_map'); ?>" type="text" value="<?php echo
		esc_attr($contact_map); ?>" /></p>

	<p><label for="<?php echo $this->get_field_id('contact_title'); ?>">
	<?php _e('Title:'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('contact_title'); ?>" name="<?php echo $this->get_field_name('contact_title'); ?>" type="text" value="<?php echo
		esc_attr($contact_title); ?>" /></p>        

	<p><label for="<?php echo $this->get_field_id('contact_address'); ?>">
	<?php _e('Address:'); ?></label>
        <textarea cols="25" rows="5" name="<?php echo $this->get_field_name('contact_address'); ?>" id="<?php echo $this->get_field_id('contact_address'); ?>"><?php echo
		esc_attr($contact_address); ?></textarea>
        </p>      
	<p><label for="<?php echo $this->get_field_id('contact_tels'); ?>">
	<?php _e('Tel Numbers:'); ?></label>
        <textarea cols="25" rows="5" name="<?php echo $this->get_field_name('contact_tels'); ?>" id="<?php echo $this->get_field_id('contact_tels'); ?>"><?php echo
		esc_attr($contact_tels); ?></textarea>
        </p>       
        
	<p><label for="<?php echo $this->get_field_id('contact_email'); ?>">
	<?php _e('Emails:'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('contact_email'); ?>" name="<?php echo $this->get_field_name('contact_email'); ?>" type="text" value="<?php echo
		esc_attr($contact_email); ?>" /></p>                 
    

	<?php
	}
	}

/**
 * Register all of the Highthemes WordPress widgets on startup.
 *
 * Calls 'widgets_init' action after all of the WordPress widgets have been
 * registered.

 */
function ht_widgets_init() {
	
	global $tweet_widget_number;
	$tweet_widget_number = 0;
	register_widget('HT_Recent_Posts');

	register_widget('HT_Popular_Posts');
	register_widget('HT_Recent_Tweets');
	register_widget('HT_Sub_Navigatioin');
	register_widget('HT_Flickr');
	register_widget('HT_Contact_Details');
	
	do_action('widgets_init');
}

add_action('init', 'ht_widgets_init', 1);	
?>